import { ActionCreatorWithPayload } from "@reduxjs/toolkit";
import { ElementType, FormEvent, useCallback } from "react";
import { useAppDispatch } from "../../hooks";

export type FormDataChangeHandler = (
  e: FormEvent,
  setFormData: ActionCreatorWithPayload<any>
) => void;

export const WithHocForm = (Component: ElementType) => {
  return function WithHocFormComponent({ ...props }: {
    [key: string]: any;
  }) {
    const dispatch = useAppDispatch();

    const dispatchFormData: FormDataChangeHandler = useCallback((
      { currentTarget }: any,
      setFormData: ActionCreatorWithPayload<any>
    ) => {
      const data: any = {};

      for (const input of currentTarget.elements) {
        if (input.name !== null && input.name !== '') {
          data[input.name] = input.value;
        }
      };

      dispatch(setFormData({
        data: {
          attributes: data,
        },
      }));
    }, [dispatch]);

    const handleFormDataChange: FormDataChangeHandler = (
      e: any,
      setFormData
    ) => {
      e.preventDefault();
      dispatchFormData(e, setFormData);
      e.target.reset();
    };

    props = {
      handleFormDataChange,
      ...props,
    };

    return <Component {...props} />;
  };
};
