import { ElementType, useState } from "react";

export type SearchHandler = ({ target }: any) => void;
export type DataFilterer = (data: any[]) => any[];

export const WithHocSearch = (Component: ElementType) => {
  return function WithHocSearchComponent({ ...props }: {
    [key: string]: any;
  }) {
    let [search, setSearch] = useState<string>('');

    const handleSearch: SearchHandler = ({
      target
    }: any) => setSearch(target.value);

    const filterData: DataFilterer = (data: any[]) => {
      return data.filter(datum => {
        let searchableDatum: string[] = [];

        Object.keys(datum).slice(1).forEach(attribute => {
          searchableDatum.push(String(datum[attribute]));
        });

        return searchableDatum.join(' ')
          .toLowerCase().indexOf(search.toLowerCase()) >= 0;
      });
    };

    props = {
      handleSearch,
      filterData,
      ...props,
    };

    return <Component {...props} />;
  };
};
