import secureLocalStorage from 'react-secure-storage';

export const loadItem = (
  key: string,
  failReturn: any = null,
  secure: boolean = false,
) => {
  try {
    if (secure) {
      const secureItem = secureLocalStorage.getItem(key);

      return secureItem ? secureItem : failReturn;
    }

    const item = localStorage.getItem(key);

    return item ? JSON.parse(item) : failReturn;
  } catch (err) {
    return failReturn;
  }
};

export const saveItem = (
  key: string,
  value: any,
  secure: boolean = false,
  callback: any = null
) => {
  try {
    callback && callback();

    if (secure) {
      return secureLocalStorage.setItem(key, value);
    }

    return localStorage.setItem(key, JSON.stringify(value));
  } catch (err) {}
};

export const removeItem = (key: string, secure: boolean = false) => {
  const storage = secure ? secureLocalStorage : localStorage;

  try {
    return storage.removeItem(key);
  } catch (err) {}
};
